==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/is.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Opinber tengill",
    "Photos" : "Ljósmyndir",
    "Your memories under your control" : "Haltu minningunum þínum undir þinni stjórn",
    "All media" : "Allt myndefni",
    "Videos" : "Myndskeið",
    "Albums" : "Albúm",
    "Collaborative albums" : "Samstarfsalbúm",
    "People" : "Fólk",
    "Folders" : "Möppur",
    "Favorites" : "Eftirlæti",
    "On this day" : "Á þessum degi",
    "Shared with you" : "Deilt með þér",
    "Tags" : "Merki",
    "Places" : "Staðir",
    "Map" : "Landakort",
    "Photos settings" : "Stillingar ljósmynda",
    "Mark selection as favorite" : "Merkja valið sem eftirlæti",
    "Add selection to favorites" : "Bæta vali í eftirlæti",
    "Remove selection from favorites" : "Fjarlægja valið úr eftirlætum",
    "Name of the album" : "Heiti á albúminu",
    "Location of the album" : "Staðsetning albúmsins",
    "Back" : "Til baka",
    "Add collaborators" : "Bæta við samstarfsfólki",
    "Save" : "Vista",
    "Create album" : "Búa til albúm",
    "Add to Album" : "Bæta í albúm",
    "Add selection to album {albumName}" : "Bæta vali í albúmið {albumName}",
    "Shared by" : "Deilt af",
    "Create a new album." : "Búa til nýtt albúm.",
    "Create new album" : "Búa til nýtt albúm",
    "New album" : "Nýtt albúm",
    "_%n item_::_%n photos and videos_" : ["%n atriði","%n ljósmyndir og myndskeið"],
    "Add people or groups who can edit your album" : "Bættu við fólki eða hópum sem geta breytt albúminu þínu",
    "Search people or groups" : "Leita að fólki eða hópum",
    "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
    "Group" : "Hópur",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjarlægja {collaboratorLabel} af listanum yfir samstarfsfólk",
    "Copy the public link" : "Afrita opinbera tengilinn",
    "Public link copied!" : "Opinber tengill afritaður!",
    "Copy public link" : "Afrita opinberan tengil",
    "Delete the public link" : "Eyða opinbera tenglinum",
    "Create public link share" : "Búa til sameign með opinberum tengli",
    "Share via public link" : "Deila með opinberum tengli",
    "Failed to fetch collaborators list." : "Mistókst að ná í lista með samstarfsfólki.",
    "Failed to update album." : "Mistókst að uppfæra albúm.",
    "This collection does not exist" : "Þetta safn er ekki til",
    "An error occurred" : "Villa kom upp",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n óúthlutuð ljósmynd","%n óúthlutaðar ljósmyndir"],
    "Favorite" : "Eftirlæti",
    "Select image {imageName}" : "Veldu mynd {imageName}",
    "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
    "There are no photos or videos yet!" : "Það eru enn engar ljósmyndir eða myndskeið!",
    "Add to {destination}" : "Bæta í {destination}",
    "Go back" : "Fara til baka",
    "Back to {folder}" : "Til baka í {folder}",
    "Share this folder" : "Deila þessari möppu",
    "_{years} year ago_::_{years} years ago_" : ["Fyrir {years} ári","Fyrir {years} árum"],
    "Enable squared photos view" : "Virkja sýn með ferköntuðum myndum",
    "Default Photos upload and Albums location" : "Sjálfgefin staðsetning fyrir innsendingar ljósmynda og albúma",
    "Choose default Photos upload and Albums location" : "Veldu sjálfgefna staðsetningu fyrir innsendingar ljósmynda og albúma",
    "Select the default location for your media" : "Veldu sjálfgefna staðsetningu fyrir myndefnið þitt",
    "Invalid location selected" : "Ógild staðsetning valin",
    "View" : "Skoða",
    "Photos directory" : "Ljósmyndamappa",
    "_%n photo_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
    "Unselect all" : "Afvelja allt",
    "Manage collaborators for this album" : "Sýsla með samstarfsfólk fyrir þetta albúm",
    "Open actions menu" : "Opna aðgerðavalmynd",
    "Edit album details" : "Sýsla með nánari upplýsingar um albúm",
    "Download all files in album" : "Sækja allar skrár í albúmi",
    "Delete album" : "Eyða albúmi",
    "Download selected files" : "Sækja valdar skrár",
    "Remove selection from album" : "Fjarlægja valið úr albúmi",
    "This album does not have any photos or videos yet!" : "Þetta albúm er enn ekki með neinar ljósmyndir eða  myndskeið!",
    "Add photos to this album" : "Bæta við ljósmyndum í þetta albúm",
    "Add photos to {albumName}" : "Bæta við ljósmyndum í {albumName}",
    "Manage collaborators" : "Sýsla með samstarfsfólk",
    "Save collaborators for this album." : "Vista samstarfsfólk fyrir þetta albúm.",
    "Cover photo for album {albumName}" : "Forsíðumynd fyrir albúmið {albumName}",
    "There is no album yet!" : "Það er enn ekkert albúm!",
    "This person could not be found" : "Þessi einstaklingur fannst ekki",
    "Rename person" : "Endurnefna einstakling",
    "Merge with different person" : "Sameina við annan einstakling",
    "Download selected photos" : "Sækja valdar ljósmyndir",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Remove person" : "Fjarlægja einstakling",
    "Name of this person" : "Nafn þessa einstaklings",
    "Save." : "Vista.",
    "Merge person" : "Sameina einstaklinga",
    "Move to different person" : "Færa á annan einstakling",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Færa mynd á annan einstakling","Færa myndir á annan einstakling"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjarlægja mynd af einstaklingi","Fjarlægja myndir af einstaklingi"],
    "This might take some time depending on the size of your photo library." : "Þetta ferli getur tekið nokkurn tíma eftir stærð ljósmyndasafnsins þíns.",
    "Recognized people will show up here" : "Fólk sem þekkist mun birtast hér",
    "This folder does not exist" : "Þessi mappa er ekki til",
    "Loading folders …" : "Hleð inn möppum …",
    "No photos in here" : "Engar ljósmyndir hér",
    "Taken on {date} at {time}" : "Tekin þann {date} kl. {time}",
    "This place does not have any photos or videos yet!" : "Þessi staður er enn ekki með neinar ljósmyndir eða  myndskeið!",
    "Add photos to this place" : "Bæta við ljósmyndum á þennan stað",
    "Cover photo for place {placeName}" : "Forsíðumynd fyrir staðinn {placeName}",
    "There is no place yet!" : "Það er enn enginn staður!",
    "Cover photo for shared album {albumName}." : "Forsíðumynd fyrir sameiginlega albúmið {albumName}.",
    "Back to tags overview" : "Fara aftur í yfirlit merkja",
    "No photos with this tag yet" : "Ennþá engar ljósmyndir með þessu merki",
    "No tags yet" : "Engin merki ennþá",
    "Photos with tags will show up here" : "Ljósmyndir með merkjum munu birtast hér",
    "Popular tags" : "Vinsæl merki",
    "Add" : "Bæta við",
    "Add to album" : "Bæta í albúm",
    "Delete selection" : "Eyða vali",
    "No photos or videos in here" : "Engar ljósmyndir eða myndskeið hér",
    "Unassigned faces" : "Óúthlutuð andlit",
    "_%n photos_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
    "Failed to fetch collection." : "Mistókst að sækja safn.",
    "Failed to fetch collections list." : "Mistókst að ná í lista með söfnum.",
    "Failed to fetch faces list." : "Mistókst að ná í lista með andlitum.",
    "All your media" : "Allt myndefnið þitt",
    "Album {title}" : "Albúm {title}",
    "Shared Albums" : "Sameiginleg albúm",
    "Shared album {title}" : "Sameiginlegt albúm {title}",
    "Public album {title}" : "Opinbert albúm {title}",
    "Tagged photos" : "Merktar ljósmyndir",
    "Tagged photo {title}" : "Merkt ljósmynd {title}",
    "{title}'s face" : "Andlit á {title}",
    "{startDate} to {endDate}" : "{startDate} til {endDate}",
    "Details" : "Nánar",
    "Failed to rename {oldName} to {faceName}." : "Mistókst að endurnefna {oldName} sem {faceName}.",
    "Failed to delete {faceName}." : "Tókst ekki að eyða {faceName}.",
    "Failed to delete {fileId}." : "Tókst ekki að eyða {fileId}.",
    "Failed to delete {fileName}." : "Tókst ekki að eyða {fileName}.",
    "Failed to set favorite state for {fileId}." : "Mistókst að setja stöðu sem eftirlæti fyrir {fileId}.",
    "Failed to set favorite state for {fileName}." : "Mistókst að setja stöðu sem eftirlæti fyrir {fileName}.",
    "Go back to the previous view." : "Fara til baka á fyrri sýn.",
    "Go to the add collaborators view." : "Skipta yfir í sýn með samstarfsfólki.",
    "Create the album." : "Búa til albúmið.",
    "Back to the new album form." : "Aftur á innfyllingarformið fyrir ný albúm.",
    "_Share with %n user_::_Share with %n users_" : ["Deila með %n notanda","Deila með %n notendum"],
    "Search for collaborators" : "Leita að samstarfsfólki",
    "Add {collaboratorLabel} to the collaborators list" : "Bæta {collaboratorLabel} á listann yfir samstarfsfólk",
    "No collaborators available" : "Ekkert samstarfsfólk tiltækt",
    "Failed to fetch album." : "Mistókst að sækja albúm.",
    "The file is in the favorites" : "Skráin er í eftirlætunum",
    "Open the \"{name}\" sub-directory" : "Opna \"{name}\" undirmöppuna",
    "Add photos to the album" : "Bæta myndum í albúmið",
    "Failed to fetch albums list." : "Mistókst að ná í lista með albúmum.",
    "Shared albums" : "Sameiginleg albúm",
    "Create a new album" : "Búa til nýtt albúm",
    "Add selection to an album" : "Bæta vali í albúm",
    "Failed to create {albumName}." : "Gat ekki búið til {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Mistókst að endurnefna {currentAlbumName} sem {newAlbumName}."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/is.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Opinber tengill",
    "Photos" : "Ljósmyndir",
    "On This Day" : "Á þessum degi",
    "Your memories under your control" : "Haltu minningunum þínum undir þinni stjórn",
    "All media" : "Allt myndefni",
    "Videos" : "Myndskeið",
    "Albums" : "Albúm",
    "Collaborative albums" : "Samstarfsalbúm",
    "People" : "Fólk",
    "Folders" : "Möppur",
    "Favorites" : "Eftirlæti",
    "On this day" : "Á þessum degi",
    "Shared with you" : "Deilt með þér",
    "Tags" : "Merki",
    "Places" : "Staðir",
    "Map" : "Landakort",
    "Photos settings" : "Stillingar ljósmynda",
    "Mark selection as favorite" : "Merkja valið sem eftirlæti",
    "Add selection to favorites" : "Bæta vali í eftirlæti",
    "Remove selection from favorites" : "Fjarlægja valið úr eftirlætum",
    "Name of the album" : "Heiti á albúminu",
    "Location of the album" : "Staðsetning albúmsins",
    "Back" : "Til baka",
    "Add collaborators" : "Bæta við samstarfsfólki",
    "Save" : "Vista",
    "Create album" : "Búa til albúm",
    "Add to Album" : "Bæta í albúm",
    "Add selection to album {albumName}" : "Bæta vali í albúmið {albumName}",
    "Shared by" : "Deilt af",
    "Create a new album." : "Búa til nýtt albúm.",
    "Create new album" : "Búa til nýtt albúm",
    "New album" : "Nýtt albúm",
    "_%n item_::_%n photos and videos_" : ["%n atriði","%n ljósmyndir og myndskeið"],
    "Failed to fetch collaborators list." : "Mistókst að ná í lista með samstarfsfólki.",
    "Failed to update album." : "Mistókst að uppfæra albúm.",
    "Add people or groups who can edit your album" : "Bættu við fólki eða hópum sem geta breytt albúminu þínu",
    "Search people or groups" : "Leita að fólki eða hópum",
    "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
    "Group" : "Hópur",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjarlægja {collaboratorLabel} af listanum yfir samstarfsfólk",
    "Copy the public link" : "Afrita opinbera tengilinn",
    "Public link copied!" : "Opinber tengill afritaður!",
    "Copy public link" : "Afrita opinberan tengil",
    "Delete the public link" : "Eyða opinbera tenglinum",
    "Create public link share" : "Búa til sameign með opinberum tengli",
    "Share via public link" : "Deila með opinberum tengli",
    "This collection does not exist" : "Þetta safn er ekki til",
    "An error occurred" : "Villa kom upp",
    "No picture for this day" : "Engin mynd frá þessum degi",
    "Picture taken on this day will show up here." : "Myndir teknar á þessum degi munu birtast hér.",
    "More photos from this day" : "Fleiri ljósmyndir frá þessum degi",
    "_%n photos_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n óúthlutuð ljósmynd","%n óúthlutaðar ljósmyndir"],
    "Favorite" : "Eftirlæti",
    "Favorite image, open the full size \"{name}\" image" : "Eftirlætismynd, opna myndina \"{name}\" í fullri stærð",
    "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
    "Select image {imageName}" : "Veldu mynd {imageName}",
    "Open the \"{name}\" folder" : "Opna \"{name}\" möppuna",
    "Go back" : "Fara til baka",
    "Dates" : "Dagsetningar",
    "Jump to specific date in list" : "Hoppa á ákveðna dagsetningu í lista",
    "Jump to {date}" : "Hoppa á {date}",
    "Add to {destination}" : "Bæta í {destination}",
    "The destination folder is owned by {owner}" : "Móttökumappan er í eigu {owner}",
    "There are no photos or videos yet!" : "Það eru enn engar ljósmyndir eða myndskeið!",
    "_{years} year ago_::_{years} years ago_" : ["Fyrir {years} ári","Fyrir {years} árum"],
    "Enable squared photos view" : "Virkja sýn með ferköntuðum myndum",
    "Delete source directory" : "Eyða upprunamöppu",
    "Select a source folder for your media" : "Veldu upprunamöppu fyrir myndefnið þitt",
    "All folders" : "Allar möppur",
    "Add a Photos source for the timelines" : "Bæta við upptökum ljósmynda fyrir tímalínurnar",
    "Add folder" : "Bæta við möppu",
    "Select the default upload location for your media" : "Veldu sjálfgefna staðsetningu innsendinga fyrir myndefnið þitt",
    "Home" : "Heim",
    "Choose default Photos upload and Albums location" : "Veldu sjálfgefna staðsetningu fyrir innsendingar ljósmynda og albúma",
    "Choose a different folder" : "Velja aðra möppu",
    "View" : "Skoða",
    "Media folders" : "Margmiðlunarmöppur",
    "Choose the folders from where photos and videos are shown." : "Veldu möppurnar þaðan sem birtar ljósmyndir og myndskeið eru tekin.",
    "Upload folder" : "Senda inn möppu",
    "Choose the folder where photos and albums are uploaded to." : "Veldu möppurnar þangað sem ljósmyndir og myndskeið eru send.",
    "_%n photo_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
    "Unselect all" : "Afvelja allt",
    "Add photos to this album" : "Bæta við ljósmyndum í þetta albúm",
    "Manage collaborators for this album" : "Sýsla með samstarfsfólk fyrir þetta albúm",
    "Open actions menu" : "Opna aðgerðavalmynd",
    "Edit album details" : "Sýsla með nánari upplýsingar um albúm",
    "Download all files in album" : "Sækja allar skrár í albúmi",
    "Delete album" : "Eyða albúmi",
    "Download selected files" : "Sækja valdar skrár",
    "Remove selection from album" : "Fjarlægja valið úr albúmi",
    "This album does not have any photos or videos yet!" : "Þetta albúm er enn ekki með neinar ljósmyndir eða  myndskeið!",
    "Add photos to {albumName}" : "Bæta við ljósmyndum í {albumName}",
    "Manage collaborators" : "Sýsla með samstarfsfólk",
    "Save collaborators for this album." : "Vista samstarfsfólk fyrir þetta albúm.",
    "Cover photo for album {albumName}" : "Forsíðumynd fyrir albúmið {albumName}",
    "There is no album yet!" : "Það er enn ekkert albúm!",
    "This person could not be found" : "Þessi einstaklingur fannst ekki",
    "Rename person" : "Endurnefna einstakling",
    "Merge with different person" : "Sameina við annan einstakling",
    "Download selected photos" : "Sækja valdar ljósmyndir",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Remove person" : "Fjarlægja einstakling",
    "Name of this person" : "Nafn þessa einstaklings",
    "Save." : "Vista.",
    "Merge person" : "Sameina einstaklinga",
    "Move to different person" : "Færa á annan einstakling",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Færa mynd á annan einstakling","Færa myndir á annan einstakling"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjarlægja mynd af einstaklingi","Fjarlægja myndir af einstaklingi"],
    "This might take some time depending on the size of your photo library." : "Þetta ferli getur tekið nokkurn tíma eftir stærð ljósmyndasafnsins þíns.",
    "Recognized people will show up here" : "Fólk sem þekkist mun birtast hér",
    "This folder does not exist" : "Þessi mappa er ekki til",
    "Loading folders …" : "Hleð inn möppum …",
    "No photos in here" : "Engar ljósmyndir hér",
    "Taken on {date} at {time}" : "Tekin þann {date} kl. {time}",
    "This place does not have any photos or videos yet!" : "Þessi staður er enn ekki með neinar ljósmyndir eða  myndskeið!",
    "Add photos to this place" : "Bæta við ljósmyndum á þennan stað",
    "Cover photo for place {placeName}" : "Forsíðumynd fyrir staðinn {placeName}",
    "There is no place yet!" : "Það er enn enginn staður!",
    "Back to tags overview" : "Fara aftur í yfirlit merkja",
    "No photos with this tag yet" : "Ennþá engar ljósmyndir með þessu merki",
    "No tags yet" : "Engin merki ennþá",
    "Photos with tags will show up here" : "Ljósmyndir með merkjum munu birtast hér",
    "Popular tags" : "Vinsæl merki",
    "All tags" : "Öll merki",
    "One of the source folders does not exist" : "Ein af upprunamöppunum er ekki til",
    "Add to album" : "Bæta í albúm",
    "Delete selection" : "Eyða vali",
    "No photos or videos in here" : "Engar ljósmyndir eða myndskeið hér",
    "Unassigned faces" : "Óúthlutuð andlit",
    "Failed to fetch collection." : "Mistókst að sækja safn.",
    "Failed to fetch collections list." : "Mistókst að ná í lista með söfnum.",
    "Failed to fetch faces list." : "Mistókst að ná í lista með andlitum.",
    "All your media" : "Allt myndefnið þitt",
    "Album {title}" : "Albúm {title}",
    "Shared Albums" : "Sameiginleg albúm",
    "Shared album {title}" : "Sameiginlegt albúm {title}",
    "Public album {title}" : "Opinbert albúm {title}",
    "Tagged photos" : "Merktar ljósmyndir",
    "Tagged photo {title}" : "Merkt ljósmynd {title}",
    "{title}'s face" : "Andlit á {title}",
    "{startDate} to {endDate}" : "{startDate} til {endDate}",
    "Details" : "Nánar",
    "Could not load photos folder" : "Gat ekki að hlaðið inn ljósmyndamöppunni",
    "Back to {folder}" : "Til baka í {folder}",
    "Share this folder" : "Deila þessari möppu",
    "One of the source folders does not exists" : "Ein af upprunamöppunum er ekki til",
    "Add" : "Bæta við"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
